@@ -37,12 +37,24 @@ impl_get_ToolkitName (DBusMessageIter *iter, void *user_data)
   return droute_return_v_string (iter, atk_get_toolkit_name ());
 }
 
+static dbus_bool_t
+impl_get_ToolkitVersion (DBusMessageIter *iter, void *user_data)
+{
+  return droute_return_v_string (iter, atk_get_toolkit_version ());
+}
+
 static dbus_bool_t
 impl_get_Version (DBusMessageIter *iter, void *user_data)
 {
   return droute_return_v_string (iter, atk_get_toolkit_version ());
 }
 
+static dbus_bool_t
+impl_get_InterfaceVersion (DBusMessageIter *iter, void *user_data)
+{
+  return droute_return_v_uint32 (iter, SPI_DBUS_APPLICATION_VERSION);
+}
+
 static dbus_bool_t
 impl_get_AtspiVersion (DBusMessageIter *iter, void *user_data)
 {
@@ -117,8 +129,10 @@ static DRouteMethod methods[] = {
 
 static DRouteProperty properties[] = {
   { impl_get_ToolkitName, NULL, "ToolkitName" },
+  { impl_get_ToolkitVersion, NULL, "ToolkitVersion" },
   { impl_get_Version, NULL, "Version" },
   { impl_get_AtspiVersion, NULL, "AtspiVersion" },
+  { impl_get_InterfaceVersion, NULL, "InterfaceVersion" },
   { impl_get_Id, impl_set_Id, "Id" },
   { NULL, NULL, NULL }
 };
