@@ -19,8 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef __ATK_PRIVATE_H__
-#define __ATK_PRIVATE_H__
+#pragma once
 
 #if defined(ATK_DISABLE_SINGLE_INCLUDES) && !defined(__ATK_H_INSIDE__) && !defined(ATK_COMPILATION)
 #error "Only <atk/atk.h> can be included directly."
@@ -32,5 +31,3 @@ void _gettext_initialization (void);
 void _compact_name (gchar *name);
 
 G_END_DECLS
-
-#endif /* __ATK_PRIVATE_H__ */
