@@ -86,6 +86,8 @@
 
 #pragma once
 
+#include <glib.h>
+
 /**
  * AtspiConstants:
  *
@@ -193,6 +195,8 @@ extern "C"
  */
 #define ATSPI_SORTORDER_COUNT (7 + 1)
 
+G_STATIC_ASSERT(ATSPI_SORTORDER_COUNT == ATSPI_Collection_SORT_ORDER_LAST_DEFINED + 1);
+
   /**
    * AtspiCollectionMatchType:
    * @ATSPI_Collection_MATCH_INVALID: Indicates an error condition or
@@ -227,6 +231,8 @@ extern "C"
  **/
 #define ATSPI_MATCHTYPES_COUNT (5 + 1)
 
+G_STATIC_ASSERT(ATSPI_MATCHTYPES_COUNT == ATSPI_Collection_MATCH_LAST_DEFINED + 1);
+
   /**
    * AtspiCollectionTreeTraversalType:
    * @ATSPI_Collection_TREE_RESTRICT_CHILDREN: Restrict children tree traveral
@@ -255,6 +261,8 @@ extern "C"
  */
 #define ATSPI_TREETRAVERSALTYPE_COUNT (3 + 1)
 
+G_STATIC_ASSERT(ATSPI_TREETRAVERSALTYPE_COUNT == ATSPI_Collection_TREE_LAST_DEFINED + 1);
+
   /**
    * AtspiComponentLayer:
    * @ATSPI_LAYER_INVALID: Indicates an error condition or uninitialized value.
@@ -315,6 +323,8 @@ extern "C"
  **/
 #define ATSPI_COMPONENTLAYER_COUNT (8 + 1)
 
+G_STATIC_ASSERT(ATSPI_COMPONENTLAYER_COUNT == ATSPI_LAYER_LAST_DEFINED + 1);
+
   /**
    * AtspiTextBoundaryType:
    * @ATSPI_TEXT_BOUNDARY_CHAR: An #AtspiText instance is bounded by this
@@ -657,7 +667,9 @@ extern "C"
  *
  * One higher than the highest valid value of #AtspiStateType.
  **/
-#define ATSPI_STATETYPE_COUNT (41 + 1)
+#define ATSPI_STATETYPE_COUNT (44 + 1)
+
+G_STATIC_ASSERT(ATSPI_STATETYPE_COUNT == ATSPI_STATE_LAST_DEFINED + 1);
 
   /**
    * AtspiKeyEventType:
@@ -937,6 +949,8 @@ extern "C"
  **/
 #define ATSPI_RELATIONTYPE_COUNT (23 + 1)
 
+G_STATIC_ASSERT(ATSPI_RELATIONTYPE_COUNT == ATSPI_RELATION_LAST_DEFINED + 1);
+
   /**
    * AtspiRole:
    * @ATSPI_ROLE_INVALID: A role indicating an error condition, such as
@@ -1426,7 +1440,9 @@ extern "C"
  *
  * One higher than the highest valid value of #AtspiRole.
  */
-#define ATSPI_ROLE_COUNT (130 + 1)
+#define ATSPI_ROLE_COUNT (131 + 1)
+
+G_STATIC_ASSERT(ATSPI_ROLE_COUNT == ATSPI_ROLE_LAST_DEFINED + 1);
 
   typedef enum
   {
@@ -1541,6 +1557,175 @@ extern "C"
 
 #define ATSPI_MAX_CHILDREN 65536
 
+/**
+ * ATSPI_ACCESSIBLE_VERSION:
+ *
+ * The version of the Application D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_ACCESSIBLE_VERSION                1
+/**
+ * ATSPI_ACTION_VERSION:
+ *
+ * The version of the Action D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_ACTION_VERSION                    1
+/**
+ * ATSPI_APPLICATION_VERSION:
+ *
+ * The version of the Application D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_APPLICATION_VERSION               1
+/**
+ * ATSPI_CACHE_VERSION:
+ *
+ * The version of the Cache D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_CACHE_VERSION                     1
+/**
+ * ATSPI_COLLECTION_VERSION:
+ *
+ * The version of the Collection D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_COLLECTION_VERSION                1
+/**
+ * ATSPI_COMPONENT_VERSION:
+ *
+ * The version of the Component D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_COMPONENT_VERSION                 1
+/**
+ * ATSPI_DEVICE_EVENT_CONTROLLER_VERSION:
+ *
+ * The version of the DeviceEventController D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_DEVICE_EVENT_CONTROLLER_VERSION   1
+/**
+ * ATSPI_DEVICE_EVENT_LISTENER_VERSION:
+ *
+ * The version of the DeviceEventListener D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_DEVICE_EVENT_LISTENER_VERSION     1
+/**
+ * ATSPI_DOCUMENT_VERSION:
+ *
+ * The version of the Document D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_DOCUMENT_VERSION                  1
+/**
+ * ATSPI_EDITABLE_TEXT_VERSION:
+ *
+ * The version of the EditableText D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_EDITABLE_TEXT_VERSION             1
+/**
+ * ATSPI_EVENT_VERSION:
+ *
+ * The version of the Event D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_EVENT_VERSION                     1
+/**
+ * ATSPI_HYPERLINK_VERSION:
+ *
+ * The version of the Hyperlink D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_HYPERLINK_VERSION                 1
+/**
+ * ATSPI_HYPERTEXT_VERSION:
+ *
+ * The version of the Hypertext D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_HYPERTEXT_VERSION                 1
+/**
+ * ATSPI_IMAGE_VERSION:
+ *
+ * The version of the Image D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_IMAGE_VERSION                     1
+/**
+ * ATSPI_REGISTRY_VERSION:
+ *
+ * The version of the Registry D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_REGISTRY_VERSION                  1
+/**
+ * ATSPI_SELECTION_VERSION:
+ *
+ * The version of the Selection D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_SELECTION_VERSION                 1
+/**
+ * ATSPI_SOCKET_VERSION:
+ *
+ * The version of the Socket D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_SOCKET_VERSION                    1
+/**
+ * ATSPI_TABLE_VERSION:
+ *
+ * The version of the Table D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_TABLE_VERSION                     1
+/**
+ * ATSPI_TABLE_CELL_VERSION:
+ *
+ * The version of the TableCell D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_TABLE_CELL_VERSION                1
+/**
+ * ATSPI_TEXT_VERSION:
+ *
+ * The version of the Text D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_TEXT_VERSION                      1
+/**
+ * ATSPI_VALUE_VERSION:
+ *
+ * The version of the Value D-Bus interface.
+ *
+ * Since: 2.59
+ */
+#define ATSPI_VALUE_VERSION                     1
+
 #ifdef __cplusplus
 }
 #endif
